<?php

/* ******************   csv2avm ******************
Quick script to convert table data into AVM compliant xml files.  The script takes explicitly formatted data such that the first row contains all the tag names, columns are delimited by a pipe (|), and data within a cell must be delimited by a semi-colon (;).

This script and all included scripts were developed by Amit Kapadia at ESA/Hubble in Garching, Germany.  For an alternative method of tagging astronomical images using the AVM standard visit:
http://www.virtualastronomy.org/avmwebtool/

For documentation of the AVM standard visit:
http://www.virtualastronomy.org/avm_metadata.php#current

Questions, concerns and suggestions may be made to either:
gauthier@as.arizona.edu
lars@eso.org
lnielsen@eso.org
akapad@gmail.com

***********************   csv2avm ****************** */

//  REPLACE THE VARIABLE BELOW WITH THE RELATIVE PATH TO THE CSV FILE AND THE FOLDER YOU WISH TO CREATE
$csv = "imagedataFORAMIT2_FULL.csv";
$folder = "xmpOutput";

//  Create a directory called xmpOutput if it does not exist
@mkdir( $folder );


//  Include AVM Generator (this is a modified version than used for the web form)
include "avmgenerator/avm_generator.php";
include "avmgenerator/namespaces.php";

//  Read CSV file
$datahandle = fopen( $csv, "r");

//  From CSV file we get the first row to use as the AVM tag names
$tags = fgetcsv($datahandle, 5000, "|");

//print_r ( $tags );

while ( ($data = fgetcsv($datahandle, 5000, "|")) !== false ) {

    $data = array_combine ( $tags, $data );
    
    //  Strip HTML tags
    $data['Credit'] = strip_tags ( $data['Credit'] );
    $data['Description'] = strip_tags ( $data['Description'] );
    
    //  Replace slashes (/) in DateCreated to dashes (-)
    //$data['DateCreated'] = preg_replace("[\/]", '-', $data['DateCreated']);
    
    //  These elements need to be an array
    $data['Spatial.ReferenceDimension'] = explode( ";", $data['Spatial.ReferenceDimension'] );
    $data['Spatial.ReferenceValue'] = explode( ";", $data['Spatial.ReferenceValue'] );
    $data['Spatial.ReferencePixel'] = explode( ";", $data['Spatial.ReferencePixel'] );
    $data['Spatial.Scale'] = explode( ";", $data['Spatial.Scale'] );
    $data['Spatial.CDMatrix'] = explode( ";", $data['Spatial.CDMatrix'] );
    $data['Facility'] = explode( ";", $data['Facility'] );
    $data['Instrument'] = explode( ";", $data['Instrument'] );
    $data['Spectral.ColorAssignment'] = explode( ";", $data['Spectral.ColorAssignment'] );
    $data['Spectral.Band'] = explode( ";", $data['Spectral.Band'] );
    $data['Spectral.Bandpass'] = explode( ";", $data['Spectral.Bandpass'] );
    $data['Spectral.CentralWavelength'] = explode( ";", $data['Spectral.CentralWavelength'] );
    $data['Temporal.StartTime'] = explode( ";", $data['Temporal.StartTime'] );
    $data['Temporal.IntegrationTime'] = explode( ";", $data['Temporal.IntegrationTime'] );
    $data['DatasetID'] = explode( ";", $data['DatasetID'] );
    $data['ResourceID'] = explode( ";", $data['ResourceID'] );
    $data['Subject.Category'] = explode( ";", $data['Subject.Category'] );
    $data['Subject.Name'] = explode( ";", $data['Subject.Name'] );
    
    //  IPTC Data (8 tags)    
    $iptcData = array( 'CiUrlWork' => $data['CreatorURL'], 'CiEmailWork' => $data['Contact.Email'], 'CiTelWork' => $data['Contact.Telephone'], 'CiAdrExtadr' => $data['Contact.Address'], 'CiAdrCity' => $data['Contact.City'], 'CiAdrRegion' => $data['Contact.StateProvince'], 'CiAdrPcode' => $data['Contact.PostalCode'], 'CiAdrCtry' => $data['Contact.Country'] );
    
    //  Photoshop Data (4 tags)
    $photoshopData = array( 'Source' => $data['Creator'], 'Headline' => $data['Headline'], 'Credit' => $data['Credit'], 'DateCreated' => $data['Date'] );

    //  Dublin Core Data (3 tags)
    $dublinCoreData = array( 'creator' => $data['Creator'], 'subject' => $data['Subject.Name'], 'description' => $data['Description'], 'title' => $data['Title'] );
    
    //  XMP Rights Data (1 tags)
    $xmpRightsData = array( 'UsageTerms' => $data['Rights'] );

    //  AVM Data (31 tags 4 missing from some subset)
    $avmData = array( 'ID' => $data['id'], 'Subject.Category' => $data['Subject.Category'], 'ReferenceURL' => $data['ReferenceURL'], 'Type' => $data['Type'], 'Image.ProductQuality' => $data['Image.ProductQuality'], 'Spectral.ColorAssignment' => $data['Spectral.ColorAssignment'], 'Spectral.Band' => $data['Spectral.Band'], 'Spectral.Bandpass' => $data['Spectral.Bandpass'], 'Spectral.CentralWavelength' => $data['Spectral.CentralWavelength'], 'Spectral.Notes' => $data['Spectral.Notes'], 'Temporal.StartTime' => $data['Temporal.StartTime'], 'Temporal.IntegrationTime' => $data['Temporal.IntegrationTime'], 'DatasetID' => $data['DatasetID'], 'Spatial.ReferenceDimension' => $data['Spatial.ReferenceDimension'], 'Spatial.CoordinateFrame' => $data['Spatial.CoordinateFrame'], 'Spatial.Equinox' => $data['Spatial.Equinox'], 'Spatial.ReferenceValue' => $data['Spatial.ReferenceValue'], 'Spatial.ReferencePixel' => $data['Spatial.ReferencePixel'], 'Spatial.Scale' => $data['Spatial.Scale'], 'Spatial.Rotation' => $data['Spatial.Rotation'], 'Spatial.CoordsystemProjection' => $data['Spatial.CoordsystemProjection'], 'Spatial.CDMatrix' => $data['Spatial.CDMatrix'], 'Spatial.Quality' => $data['Spatial.Quality'], 'Spatial.Notes' => $data['Spatial.Notes'], 'Publisher' => $data['Publisher'], 'PublisherID' => $data['PublisherID'], 'ResourceID' => $data['ResourceID'], 'MetadataVersion' => $data['MetadataVersion'], 'Facility' => $data['Facility'], 'Instrument' => $data['Instrument'], 'Spatial.Rotation' => $data['Spatial.Rotation'], 'ResourceURL' => $data['ResourceURL'], 'RelatedResources' => $data['RelatedResources'], 'MetadataDate' => $data['MetadataDate'] );
        
    //$differenceData = array_merge ( $iptcData, $photoshopData, $dublinCoreData, $xmpRightsData );
    //$avmData = array_diff ( $data, $differenceData );
 
    //  Create a new file to write using the ID field
    $filename = $data['id'];
    $handle = fopen("$folder/$filename.xmp", "w");
    
    //  Write data
    write_header ( $handle );
        write_data ( $iptcData, $iptc_ns, $handle );
        write_data ( $photoshopData, $photoshop_ns, $handle );
        write_data ( $dublinCoreData, $dc_ns, $handle );
        write_data ( $avmData, $avm_ns, $handle );
        write_data ( $xmpRightsData, $xaprights_ns, $handle );    
    write_closer ( $handle );
    fclose($handle);

}   

fclose($datahandle);
?>